@@ -133,15 +133,15 @@ esac; done;
 shift $((OPTIND-1))
 
 if (( $# == 0 )) || [ "X$1" = "Xall" ]; then
-    set -- ubuntu kubuntu kubuntu-kde4 edubuntu xubuntu gobuntu base
+    set -- ubuntu kubuntu kubuntu-kde4 edubuntu xubuntu mythbuntu gobuntu base
     if [ "$ARCH" = "i386" ]; then
-        set -- ubuntu ubuntu-dvd kubuntu kubuntu-dvd kubuntu-kde4 edubuntu edubuntu-dvd xubuntu gobuntu base
+        set -- ubuntu ubuntu-dvd kubuntu kubuntu-dvd kubuntu-kde4 edubuntu edubuntu-dvd mythbuntu xubuntu gobuntu base
     fi
 fi
 
 for arg in "$@"; do
     case "$arg" in
-       ubuntu|ubuntu-dvd|ubuntu-lpia|edubuntu|edubuntu-dvd|kubuntu|kubuntu-dvd|kubuntu-kde4|xubuntu|gobuntu|ubuntu-mid|ubuntu-mobile|base|tocd)
+       ubuntu|ubuntu-dvd|ubuntu-lpia|edubuntu|edubuntu-dvd|kubuntu|kubuntu-dvd|kubuntu-kde4|xubuntu|mythbuntu|gobuntu|ubuntu-mid|ubuntu-netbook-remix|base|tocd)
 	    ;;
 	*)
 	    echo bad name >&2;
@@ -199,16 +199,21 @@ Flags: seen
 	    LIVELIST="gobuntu-live^ laptop-detect casper lupin-casper"
 	    COMP="main"
 	    ;;
-    ubuntu-mid)
-        LIST="$LIST minimal^ ubuntu-mid"
-        LIVELIST="casper ubiquity"
-        COMP="main restricted universe multiverse"
-        ;;
-        ubuntu-mobile)
-            LIST="$LIST minimal^ mobile-mobile^"
-            LIVELIST="casper ubiquity"
-            COMP="main restricted universe multiverse"
-            ;;
+	ubuntu-mid)
+	    LIST="$LIST minimal^ mobile-mid^"
+	    LIVELIST="mobile-live^ casper ubiquity"
+	    COMP="main restricted universe multiverse"
+	    ;;
+	ubuntu-netbook-remix)
+	    LIST="$LIST minimal^ standard^ mobile-netbook-remix^"
+	    LIVELIST="mobile-live^ casper ubiquity"
+	    COMP="main restricted universe"
+	    ;;
+	mythbuntu)
+	    LIST="$LIST minimal^ standard^ mythbuntu-desktop"
+	    LIVELIST="mythbuntu-live laptop-detect casper lupin-casper"
+	    COMP="main restricted universe multiverse"
+	    ;;
 	base)
 	    LIST="$LIST minimal^ standard^"
 	    LIVELIST="casper lupin-casper"
@@ -318,6 +323,7 @@ link_in_boot = $link_in_boot
 	hppa)		LIST="$LIST linux-hppa32 linux-hppa64";;
 	powerpc)	LIST="$LIST linux-powerpc linux-powerpc64-smp";;
 	sparc*)		LIST="$LIST linux-sparc64";;
+	armel)		LIST="$LIST linux-imx51 linux-headers-imx51";;
 	*)		echo "Unknown architecture: no kernel."; exit 1;;
     esac
 
@@ -359,7 +365,7 @@ Pin-Priority: 900
     fi
     chroot $ROOT apt-get update
     chroot $ROOT apt-get -y --purge dist-upgrade </dev/null
-    chroot $ROOT apt-get -y install $LIST </dev/null
+    chroot $ROOT apt-get -y --purge install $LIST </dev/null
 
     # launchpad likes to put dependencies of seeded packages in tasks along with the
     # actual seeded packages.  In general, this isn't an issue.  With updated kernels
@@ -375,12 +381,12 @@ Pin-Priority: 900
     done
     rm -f livecd.${FSS}.manifest-headers livecd.${FSS}.manifest-headers-full
     chroot ${ROOT} apt-get -y --purge remove $HEADERPACKAGES </dev/null || true
-    chroot ${ROOT} apt-get -y install $HEADERMETA </dev/null || true
+    chroot ${ROOT} apt-get -y --purge install $HEADERMETA </dev/null || true
     # End horrible linux-header launchpad workaround.  Hopefully this is temporary.
 
     chroot ${ROOT} dpkg-query -W --showformat='${Package} ${Version}\n' \
 	> livecd.${FSS}.manifest-desktop
-    chroot $ROOT apt-get -y install $LIVELIST </dev/null
+    chroot $ROOT apt-get -y --purge install $LIVELIST </dev/null
     case $FS in
 	edubuntu)
 	    chroot $ROOT apt-cache dumpavail | \
@@ -473,6 +479,9 @@ ${COMMENT}deb-src ${SECSRCMIRROR} ${STE}-security multiverse
     rm -f ${ROOT}var/spool/postfix/maildrop/*
     # Removing update-notifier notes is now considered harmful:
     #rm -f ${ROOT}var/lib/update-notifier/user.d/*
+    # The D-Bus machine identifier needs to be unique, and is generated at
+    # boot time if it's missing.
+    rm -f ${ROOT}var/lib/dbus/machine-id
     chroot $ROOT apt-get update || true	# give them fresh lists, but don't fail
     rm -f ${ROOT}etc/resolv.conf ${ROOT}etc/mailname
     if [ -f ${ROOT}/etc/postfix/main.cf ]; then
